# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals
__all__ = [
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__"
]

__title__ = "swagger-spec-validator"
__summary__ = "Validation of Swagger specifications"
__uri__ = "http://github.com/Yelp/swagger_spec_validator"

__version__ = "2.7.5"

__author__ = "Yelp"
__email__ = "core-services@yelp.com"

__license__ = "Apache License, Version 2.0"
